from .create_note import create_note
from .open_note import open_note
from .config import Config
from argparse import ArgumentParser

def main():
    parser = ArgumentParser(usage='pystickynote name [OPTIONS]')
    parser.add_argument('action', choices=['open', 'create'], help='Action to run. Either "open" or "create".')
    parser.add_argument('name', help='Stickynote\'s name to save to', type=str)
    args = parser.parse_args()
    config = Config()
    if args.action == 'create':
        create_note(args.name, config)
    elif args.action == 'open':
        open_note(args.name, config)
    exit(0)

if __name__ == "__main__":
    main()


from pystickynote.paths import NOTES_PATH
import PySimpleGUIQt as g
import sys
import json

if 'darwin' in sys.platform:
    NTB = False
else:
    NTB = True
    
    
def open_note(name, config):
    g.SetOptions(background_color=config.background_color, text_color=config.text_color,
                 input_elements_background_color=config.background_color, input_text_color=config.text_color,
                 button_color=(config.text_color, config.background_color), border_width=0)
    with open(NOTES_PATH, 'r+') as notes:
        note_obj = json.load(notes)
        match = False
        content = ''
        for k, v in note_obj.items():
            if name == k:
                match = True
                content = v
        if match == False:
            print('No Note Found With That Name')
            exit(1)
        layout = [
            [g.T(name, font=('Arial', 8), justification='center')],
            [g.Multiline(content, size=(50, 5), key='content')],
            [g.B('Close'), g.B('Delete'), g.B('Save')]
        ]
        
        window = g.Window('Create', no_titlebar=NTB, keep_on_top=True, grab_anywhere=True, layout=layout, alpha_channel=float(config.alpha))
        
        while True:
            event, value = window.Read()
            if event == 'Close':
                window.Close()
                break
            elif event == 'Save':
                note_obj[name] = value['content']
                notes.seek(0)
                notes.truncate()
                json.dump(note_obj, notes, indent=4)
                window.Close()
                break
            elif event == 'Delete':
                new_layout = [
                    [g.T('Are you sure you want to delete {}?'.format(name), justification='center')],
                    [g.B('No'), g.B('Yes')]
                ]
                confirm_window = g.Window('', no_titlebar=NTB, keep_on_top=True, grab_anywhere=True, layout=new_layout)
                while True:
                    event1, value1 = confirm_window.Read()
                    if event1 == 'Yes':
                        note_obj.pop(name, [])
                        notes.seek(0)
                        notes.truncate()
                        json.dump(note_obj, notes, indent=4)
                        confirm_window.Close()
                    else:
                        confirm_window.Close()
                confirm_window.Close()
                window.Close()
                break
        sys.exit(0)
                
                


from pystickynote.paths import CONFIG_PATH
from configparser import ConfigParser

class Config:
    def __init__(self):
        self.config = ConfigParser()
        self.config.read(CONFIG_PATH)
        self.config_dict = self.config['DEFAULT']
        self.background_color = self.config_dict['background_color']
        self.text_color = self.config_dict['text_color']
        self.alpha = self.config_dict['alpha']


from pystickynote.paths import NOTES_PATH
import PySimpleGUIQt as g
import sys
import json

if 'darwin' in sys.platform:
    NTB = False
else:
    NTB = True

def create_note(name, config):
    g.SetOptions(background_color=config.background_color, text_color=config.text_color,
                 input_elements_background_color=config.background_color, input_text_color=config.text_color,
                 button_color=(config.text_color, config.background_color), border_width=0)
    layout = [
        [g.T('Create Note', font=('Arial', 8), justification='center')],
        [g.Multiline('', size=(50, 5), key='content')],
        [g.B('Close'), g.B('Save')]
    ]
    window = g.Window('Create', no_titlebar=NTB, keep_on_top=True, grab_anywhere=True, layout=layout, alpha_channel=float(config.alpha))
    while True:
        event, value = window.Read()
        if event == 'Close':
            window.Close()
            break
        elif event == 'Save':
            with open(NOTES_PATH, 'r+') as notes:
                note_obj = json.load(notes)
                note_obj.update({
                    name: value['content']
                })
                notes.seek(0)
                notes.truncate()
                json.dump(note_obj, notes, indent=4)
            window.Close()
            break


import sys, requests
from setuptools import setup, find_packages
import os
setup(
    name='pystickynote',
    version='1.0.0',
    author='Max Bridgland',
    author_email='mabridgland@protonmail.com',
    description='Easy Sticky Note Widgets',
    long_description="",
    long_description_content_type='text/markdown',
    url='https://github.com/M4cs/pystickynote',
    packages=['pystickynote'],
    install_requires=[
        'PySimpleGUIQt'
    ],
    project_urls={
        'Discord Server': 'https://discordapp.com/invite/7VN9VZe'
    },
    license='GNU General Public License v3 (GPLv3) (GPL)',
    zip_safe=True,
    entry_points={
        'console_scripts':[
            'pystickynote = pystickynote.__main__:main',
        ],
    },
    data_files=[(str(os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote')), []), (str(os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote')), ['./pysn.conf', './pysn.conf'])],
    classifiers=[  # Used by PyPI to classify the project and make it searchable
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',

        'Programming Language :: Python',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',

        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: IronPython',
        'Programming Language :: Python :: Implementation :: Jython',

        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'Intended Audience :: Information Technology',

        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Libraries',
        'Topic :: System :: Systems Administration',
        'Topic :: System :: Networking',
        'Topic :: Utilities',
    ]
)
